@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.015_02';
+our $VERSION = '0.015_03';
 $VERSION = eval $VERSION;
 
 sub new {
@@ -27,16 +27,18 @@ sub get {
 
   my $filename = $repo->get_file($self->filename);
   if ( my $new_filename = $repo->{new_filename} ) {
-    $filename = $self->{filename} = $new_filename;
+    $filename = $new_filename;
   }
 
+  ## whatever happened, record the new filename
+  $self->{filename} = $filename;
 
   if (defined $self->{sha1} || defined $self->{sha256}) {
     unless (eval 'require Digest::SHA') {
       warn "sha1 or sha256 sums are specified but cannot be checked since Digest::SHA is not installed";
       return $filename;
     }
-  
+
     eval 'require Digest::SHA' or return $filename;
     ## verify that the SHA-1 and/or SHA-256 sums match if provided
     if (defined $self->{sha1}) {
@@ -59,7 +61,7 @@ sub get {
     }
   }
 
-  return $self->filename;
+  return $filename;
 }
 
 sub platform   { shift->{platform}   }
